# Código de Conduta do Pacto do Contribuidor

## Nosso Compromisso

Nós, como membros, colaboradores e líderes, nos comprometemos a tornar a participação em nossa  
comunidade uma experiência livre de assédio para todos, independentemente de idade, tamanho corporal,  
deficiência visível ou invisível, etnia, características sexuais, identidade e expressão de gênero,  
nível de experiência, educação, status socioeconômico, nacionalidade, aparência pessoal, raça, religião,  
ou identidade e orientação sexual.  

Nos comprometemos a agir e interagir de maneiras que contribuam para uma comunidade aberta, acolhedora,  
diversa, inclusiva e saudável.

## Nossos Padrões

Exemplos de comportamentos que contribuem para um ambiente positivo em nossa comunidade incluem:

* Demonstrar empatia e gentileza em relação às outras pessoas  
* Ser respeitoso com opiniões, pontos de vista e experiências diferentes  
* Dar e aceitar com elegância feedbacks construtivos  
* Assumir responsabilidade e pedir desculpas àqueles afetados por nossos erros, e aprender com a experiência

* Focar no que é melhor não apenas para nós como indivíduos, mas para a comunidade como um todo

Exemplos de comportamentos inaceitáveis incluem:

* O uso de linguagem ou imagens sexualizadas, e atenção ou avanços sexuais de qualquer tipo

* Comentários de trollagem, insultos ou depreciativos, e ataques pessoais ou políticos
* Assédio público ou privado
* Publicar informações privadas de terceiros, como um endereço físico ou de e-mail, sem sua permissão explícita

* Outros comportamentos que possam razoavelmente ser considerados inadequados em um ambiente profissional

## Responsabilidades de Fiscalização

Os líderes da **Comunidade** são responsáveis por esclarecer e fazer cumprir nossos padrões de comportamento aceitável e tomarão medidas corretivas apropriadas e justas em resposta a qualquer comportamento que considerem inadequado, ameaçador, ofensivo ou prejudicial.

Os líderes da **Comunidade** têm o direito e a responsabilidade de remover, editar ou rejeitar comentários, commits, código, edições na wiki, issues e outras contribuições que não estejam alinhadas a este Código de Conduta, e comunicarão os motivos das decisões de moderação quando apropriado.

## Escopo

Este Código de Conduta aplica-se a todos os espaços da comunidade e também quando um indivíduo está representando oficialmente a comunidade em espaços públicos. Exemplos de representação da nossa comunidade incluem o uso de um endereço de e-mail oficial, postagens por meio de uma conta oficial de mídia social ou atuar como representante designado em um evento online ou offline.

## Aplicação

Casos de comportamento abusivo, assédio ou qualquer outro comportamento inaceitável podem ser relatados aos líderes da comunidade responsáveis pela aplicação em aw@funstory.ai. Todas as reclamações serão revisadas e investigadas de forma rápida e justa.

Todos os líderes da comunidade são obrigados a respeitar a privacidade e a segurança do denunciante de qualquer incidente.

## Diretrizes de aplicação

Os líderes da comunidade seguirão estas Diretrizes de Impacto na Comunidade para determinar
as consequências de qualquer ação que considerem em violação deste Código de Conduta:

### 1. Correção

**Impacto na Comunidade**: Uso de linguagem inadequada ou outro comportamento considerado não profissional ou indesejado na comunidade.

**Consequência**: Um aviso privado e escrito dos líderes da comunidade, fornecendo clareza sobre a natureza da violação e uma explicação do porquê o comportamento foi inadequado. Um pedido público de desculpas pode ser solicitado.

### 2. Aviso

**Impacto na Comunidade**: Uma violação através de um único incidente ou série de ações.

**Consequência**: Um aviso com consequências para comportamento contínuo. Nenhuma interação com as pessoas envolvidas, incluindo interação não solicitada com aqueles que aplicam o Código de Conduta, por um período de tempo especificado. Isso inclui evitar interações em espaços da comunidade, bem como canais externos como mídias sociais. Violar esses termos pode levar a uma suspensão temporária ou banimento permanente.

### 3. Suspensão temporária

**Impacto na Comunidade**: Uma violação grave dos padrões da comunidade, incluindo comportamento inadequado contínuo.

**Consequência**: Uma suspensão temporária de qualquer tipo de interação ou comunicação pública com a comunidade por um período de tempo especificado. Nenhuma interação pública ou privada com as pessoas envolvidas, incluindo interação não solicitada com aqueles que aplicam o Código de Conduta, é permitida durante este período. Violar estes termos pode levar a uma suspensão permanente.

### 4. Banimento permanente

**Impacto na Comunidade**: Demonstração de um padrão de violação dos padrões da comunidade, incluindo comportamento inadequado contínuo, assédio a um indivíduo ou agressão ou difamação de grupos de indivíduos.

**Consequência**: Banimento permanente de qualquer tipo de interação pública dentro da comunidade.

## Atribuição

Este Código de Conduta é adaptado do [Contributor Covenant][homepage],
versão 2.0, disponível em
https://www.contributor-covenant.org/version/2/0/code_of_conduct.html.

As Diretrizes de Impacto na Comunidade foram inspiradas pela [escada de aplicação do código de conduta da Mozilla](https://github.com/mozilla/diversity).

[homepage]: https://www.contributor-covenant.org

Para respostas a perguntas frequentes sobre este código de conduta, consulte as [Perguntas frequentes](#perguntas-frequentes) em
https://www.contributor-covenant.org/faq. Traduções estão disponíveis em
https://www.contributor-covenant.org/translations.

<div align="right"> 
<h6><small>Parte do conteúdo desta página foi traduzida pelo GPT e pode conter erros.</small></h6>